@@ -1,5 +1,5 @@
 # type: ignore[attr-defined]
-"""Generic Python Package for Binary Classifications"""
+"""Generic Python Package for Binary Classifications."""
 
 import sys
 
